@@ -212,7 +212,7 @@ based on endpoint criteria:
 
 For load-balancing purposes, both Flow and Endpoint have FastHash() functions,
 which provide quick, non-cryptographic hashes of their contents.  Of particular
-importance is the fact that Flow FastHash() is symetric: A->B will have the same
+importance is the fact that Flow FastHash() is symmetric: A->B will have the same
 hash as B->A.  An example usage could be:
 
  channels := [8]chan gopacket.Packet
@@ -288,7 +288,7 @@ the packet's information.  A quick example:
    parser := gopacket.NewDecodingLayerParser(layers.LayerTypeEthernet, &eth, &ip4, &ip6, &tcp)
    decoded := []gopacket.LayerType{}
    for packetData := range somehowGetPacketData() {
-     err := parser.DecodeLayers(packetDat, &decoded)
+     err := parser.DecodeLayers(packetData, &decoded)
      for _, layerType := range decoded {
        switch layerType {
          case layers.LayerTypeIPv6:
@@ -359,7 +359,7 @@ in a lot of interesting variables/maps (DecodersByLayerName, etc).  Therefore,
 it's recommended that even if you don't use any layers functions directly, you still import with:
 
   import (
-    _ "code.google.com/p/gopacket/layers"
+    _ "github.com/google/gopacket/layers"
   )
 */
 package gopacket
