@@ -7,6 +7,7 @@ package layers
 
 import (
 	"github.com/google/gopacket"
+	"net"
 	"reflect"
 	"testing"
 )
@@ -233,6 +234,33 @@ var SFlowTestPacket5 = []byte{
 	0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x80,
 }
 
+// expanded flow sample - Ipv4 Tunnel Ingress record
+var SFlowTestPacket6 = []byte{
+	0x00, 0x00, 0x00, 0x05, 0x00, 0x00, 0x00, 0x01, 0x7f, 0x00, 0x00, 0x01,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x72, 0x00, 0x01, 0xbd, 0x50,
+	0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00, 0x48,
+	0x00, 0x00, 0x00, 0x74, 0x02, 0x00, 0x03, 0xe8, 0x00, 0x00, 0x00, 0x01,
+	0x00, 0x00, 0x00, 0x74, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x80, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x04, 0x00,
+	0x00, 0x00, 0x00, 0x20, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x2f,
+	0xc0, 0xa8, 0x00, 0x54, 0xc0, 0xa8, 0x00, 0x53, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+}
+
+// expanded flow sample - Ipv4 Tunnel Egress record
+var SFlowTestPacket7 = []byte{
+	0x00, 0x00, 0x00, 0x05, 0x00, 0x00, 0x00, 0x01, 0x7f, 0x00, 0x00, 0x01,
+	0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00, 0x12, 0x00, 0x00, 0x42, 0x68,
+	0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00, 0x48,
+	0x00, 0x00, 0x00, 0x12, 0x02, 0x00, 0x03, 0xe9, 0x00, 0x00, 0x00, 0x01,
+	0x00, 0x00, 0x00, 0x12, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x6c,
+	0x80, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00, 0x01,
+	0x00, 0x00, 0x03, 0xff, 0x00, 0x00, 0x00, 0x20, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xc0, 0xa8, 0x00, 0x54,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00,
+}
+
 func TestDecodeUDPSFlow(t *testing.T) {
 	p := gopacket.NewPacket(SFlowTestPacket1, LayerTypeEthernet, gopacket.Default)
 	if p.ErrorLayer() != nil {
@@ -991,6 +1019,124 @@ func TestDecodeExtendedRouterFlow(t *testing.T) {
 	}
 }
 
+func TestDecodeExtendedIpv4TunnelIngressFlow(t *testing.T) {
+	p := gopacket.NewPacket(SFlowTestPacket6, LayerTypeSFlow, gopacket.Default)
+
+	if p.ErrorLayer() != nil {
+		t.Error("Failed to decode packet:", p.ErrorLayer().Error())
+	}
+	checkLayers(p, []gopacket.LayerType{LayerTypeSFlow}, t)
+
+	got := p.ApplicationLayer().(*SFlowDatagram)
+
+	want := &SFlowDatagram{
+		DatagramVersion: uint32(5),
+		AgentAddress:    []byte{0x7f, 0x0, 0x0, 0x1},
+		SubAgentID:      uint32(0),
+		SequenceNumber:  uint32(0x72),
+		AgentUptime:     uint32(0x1bd50),
+		SampleCount:     uint32(1),
+		FlowSamples: []SFlowFlowSample{
+			SFlowFlowSample{
+				Format:                SFlowTypeFlowSample,
+				SampleLength:          0x48,
+				SequenceNumber:        0x74,
+				SourceIDClass:         0x0,
+				SourceIDIndex:         0x20003e8,
+				SamplingRate:          0x1,
+				SamplePool:            0x74,
+				Dropped:               0x0,
+				InputInterfaceFormat:  0x0,
+				InputInterface:        0x0,
+				OutputInterfaceFormat: 0x0,
+				OutputInterface:       0x80000001,
+				RecordCount:           0x1,
+				Records: []SFlowRecord{
+					SFlowExtendedIpv4TunnelIngressRecord{
+						SFlowBaseFlowRecord: SFlowBaseFlowRecord{
+							EnterpriseID:   0x0,
+							Format:         SFlowTypeExtendedIpv4TunnelIngressFlow,
+							FlowDataLength: 0x20,
+						},
+						SFlowIpv4Record: SFlowIpv4Record{
+							Length:   0x0,
+							Protocol: 0x2f,
+							IPSrc:    net.IP{0xc0, 0xa8, 0x0, 0x54},
+							IPDst:    net.IP{0xc0, 0xa8, 0x0, 0x53},
+							PortSrc:  0x0,
+							PortDst:  0x0,
+							TCPFlags: 0x0,
+							TOS:      0x0,
+						},
+					},
+				},
+			},
+		},
+	}
+	if !reflect.DeepEqual(want, got) {
+		t.Errorf("SFlow layer mismatch, \nwant:\n\n%#v\ngot:\n\n\n%#v\n\n", want, got)
+	}
+}
+
+func TestDecodeExtendedIpv4TunnelEgressFlow(t *testing.T) {
+	p := gopacket.NewPacket(SFlowTestPacket7, LayerTypeSFlow, gopacket.Default)
+
+	if p.ErrorLayer() != nil {
+		t.Error("Failed to decode packet:", p.ErrorLayer().Error())
+	}
+	checkLayers(p, []gopacket.LayerType{LayerTypeSFlow}, t)
+
+	got := p.ApplicationLayer().(*SFlowDatagram)
+
+	want := &SFlowDatagram{
+		DatagramVersion: uint32(5),
+		AgentAddress:    []byte{0x7f, 0x0, 0x0, 0x1},
+		SubAgentID:      uint32(1),
+		SequenceNumber:  uint32(0x12),
+		AgentUptime:     uint32(0x4268),
+		SampleCount:     uint32(1),
+		FlowSamples: []SFlowFlowSample{
+			SFlowFlowSample{
+				Format:                SFlowTypeFlowSample,
+				SampleLength:          0x48,
+				SequenceNumber:        0x12,
+				SourceIDClass:         0x0,
+				SourceIDIndex:         0x20003e9,
+				SamplingRate:          0x1,
+				SamplePool:            0x12,
+				Dropped:               0x0,
+				InputInterfaceFormat:  0x0,
+				InputInterface:        0x6c,
+				OutputInterfaceFormat: 0x0,
+				OutputInterface:       0x80000001,
+				RecordCount:           0x1,
+				Records: []SFlowRecord{
+					SFlowExtendedIpv4TunnelEgressRecord{
+						SFlowBaseFlowRecord: SFlowBaseFlowRecord{
+							EnterpriseID:   0x0,
+							Format:         SFlowTypeExtendedIpv4TunnelEgressFlow,
+							FlowDataLength: 0x20,
+						},
+						SFlowIpv4Record: SFlowIpv4Record{
+							Length:   0x0,
+							Protocol: 0x0,
+							IPSrc:    net.IP{0x0, 0x0, 0x0, 0x0},
+							IPDst:    net.IP{0xc0, 0xa8, 0x0, 0x54},
+							PortSrc:  0x0,
+							PortDst:  0x0,
+							TCPFlags: 0x0,
+							TOS:      0x0,
+						},
+					},
+				},
+			},
+		},
+	}
+	if !reflect.DeepEqual(want, got) {
+		t.Errorf("SFlow layer mismatch, \nwant:\n\n%#v\ngot:\n\n\n%#v\n\n", want, got)
+	}
+}
+
 func BenchmarkDecodeSFlowPacket1(b *testing.B) {
 	for i := 0; i < b.N; i++ {
 		gopacket.NewPacket(SFlowTestPacket1, LinkTypeEthernet, gopacket.NoCopy)
