@@ -85,10 +85,16 @@ int pcap_set_rfmon(pcap_t *p, int rfmon) {
 #elif __GLIBC__
 #define gopacket_time_secs_t __time_t
 #define gopacket_time_usecs_t __suseconds_t
+#else  // Some form of linux/bsd/etc...
+#include <sys/param.h>
+#ifdef __OpenBSD__
+#define gopacket_time_secs_t u_int32_t
+#define gopacket_time_usecs_t u_int32_t
 #else
 #define gopacket_time_secs_t time_t
 #define gopacket_time_usecs_t suseconds_t
 #endif
+#endif
 */
 import "C"
 
@@ -101,6 +107,7 @@ import (
 	"runtime"
 	"strconv"
 	"sync"
+	"sync/atomic"
 	"syscall"
 	"time"
 	"unsafe"
@@ -127,11 +134,16 @@ const bpfInstructionBufferSize = 8 * MaxBpfInstructions
 // Handles are already pcap_activate'd
 type Handle struct {
 	// cptr is the handle for the actual pcap C object.
-	cptr         *C.pcap_t
-	blockForever bool
-	device       string
-	deviceIndex  int
-	mu           sync.Mutex
+	cptr        *C.pcap_t
+	timeout     time.Duration
+	device      string
+	deviceIndex int
+	mu          sync.Mutex
+	closeMu     sync.Mutex
+	// stop is set to a non-zero value by Handle.Close to signal to
+	// getNextBufPtrLocked to stop trying to read packets
+	stop uint64
+
 	// Since pointers to these objects are passed into a C function, if
 	// they're declared locally then the Go compiler thinks they may have
 	// escaped into C-land, so it allocates them on the heap.  This causes a
@@ -210,13 +222,12 @@ func timeoutMillis(timeout time.Duration) C.int {
 func OpenLive(device string, snaplen int32, promisc bool, timeout time.Duration) (handle *Handle, _ error) {
 	buf := (*C.char)(C.calloc(errorBufferSize, 1))
 	defer C.free(unsafe.Pointer(buf))
+
 	var pro C.int
 	if promisc {
 		pro = 1
 	}
-	p := &Handle{}
-	p.blockForever = timeout < 0
-	p.device = device
+	p := &Handle{timeout: timeout, device: device}
 
 	ifc, err := net.InterfaceByName(device)
 	if err != nil {
@@ -234,6 +245,12 @@ func OpenLive(device string, snaplen int32, promisc bool, timeout time.Duration)
 	if p.cptr == nil {
 		return nil, errors.New(C.GoString(buf))
 	}
+
+	if err := p.openLive(); err != nil {
+		C.pcap_close(p.cptr)
+		return nil, err
+	}
+
 	return p, nil
 }
 
@@ -334,26 +351,37 @@ func (p *Handle) getNextBufPtrLocked(ci *gopacket.CaptureInfo) error {
 	if p.cptr == nil {
 		return io.EOF
 	}
-	var result NextError
-	for {
-		result = NextError(C.pcap_next_ex(p.cptr, &p.pkthdr, &p.bufptr))
-		if p.blockForever && result == NextErrorTimeoutExpired {
-			continue
-		}
-		break
-	}
-	if result != NextErrorOk {
-		if result == NextErrorNoMorePackets {
+
+	for atomic.LoadUint64(&p.stop) == 0 {
+		// try to read a packet if one is immediately available
+		result := NextError(C.pcap_next_ex(p.cptr, &p.pkthdr, &p.bufptr))
+
+		if result == NextErrorOk {
+			// got a packet, set capture info and return
+			sec := int64(p.pkthdr.ts.tv_sec)
+			// convert micros to nanos
+			nanos := int64(p.pkthdr.ts.tv_usec) * 1000
+
+			ci.Timestamp = time.Unix(sec, nanos)
+			ci.CaptureLength = int(p.pkthdr.caplen)
+			ci.Length = int(p.pkthdr.len)
+			ci.InterfaceIndex = p.deviceIndex
+
+			return nil
+		} else if result == NextErrorNoMorePackets {
+			// no more packets, return EOF rather than libpcap-specific error
 			return io.EOF
+		} else if result != NextErrorTimeoutExpired {
+			// we got a non-timeout error
+			return result
 		}
-		return result
+
+		// must have had a timeout... wait before trying again
+		p.waitForPacket()
 	}
-	ci.Timestamp = time.Unix(int64(p.pkthdr.ts.tv_sec),
-		int64(p.pkthdr.ts.tv_usec)*1000) // convert micros to nanos
-	ci.CaptureLength = int(p.pkthdr.caplen)
-	ci.Length = int(p.pkthdr.len)
-	ci.InterfaceIndex = p.deviceIndex
-	return nil
+
+	// stop must be set
+	return io.EOF
 }
 
 // ZeroCopyReadPacketData reads the next packet off the wire, and returns its data.
@@ -384,11 +412,19 @@ func (p *Handle) ZeroCopyReadPacketData() (data []byte, ci gopacket.CaptureInfo,
 
 // Close closes the underlying pcap handle.
 func (p *Handle) Close() {
-	p.mu.Lock()
-	defer p.mu.Unlock()
+	p.closeMu.Lock()
+	defer p.closeMu.Unlock()
+
 	if p.cptr == nil {
 		return
 	}
+
+	atomic.StoreUint64(&p.stop, 1)
+
+	// wait for packet reader to stop
+	p.mu.Lock()
+	defer p.mu.Unlock()
+
 	C.pcap_close(p.cptr)
 	p.cptr = nil
 }
@@ -481,6 +517,18 @@ func (p *Handle) compileBPFFilter(expr string) (_Ctype_struct_bpf_program, error
 	return bpf, nil
 }
 
+// CompileBPFFilter compiles and returns a BPF filter with given a link type and capture length.
+func CompileBPFFilter(linkType layers.LinkType, captureLength int, expr string) ([]BPFInstruction, error) {
+	cptr := C.pcap_open_dead(C.int(linkType), C.int(captureLength))
+	if cptr == nil {
+		return nil, errors.New("error opening dead capture")
+	}
+
+	h := Handle{cptr: cptr}
+	defer h.Close()
+	return h.CompileBPFFilter(expr)
+}
+
 // CompileBPFFilter compiles and returns a BPF filter for the pcap handle.
 func (p *Handle) CompileBPFFilter(expr string) ([]BPFInstruction, error) {
 	bpf, err := p.compileBPFFilter(expr)
@@ -511,7 +559,6 @@ func (p *Handle) SetBPFFilter(expr string) (err error) {
 	}
 
 	if -1 == C.pcap_setfilter(p.cptr, &bpf) {
-		C.pcap_freecode(&bpf)
 		return p.Error()
 	}
 
@@ -775,7 +822,9 @@ func (t TimestampSource) String() string {
 // TimestampSourceFromString translates a string into a timestamp type, case
 // insensitive.
 func TimestampSourceFromString(s string) (TimestampSource, error) {
-	t := C.pcap_tstamp_type_name_to_val(C.CString(s))
+	cs := C.CString(s)
+	defer C.free(unsafe.Pointer(cs))
+	t := C.pcap_tstamp_type_name_to_val(cs)
 	if t < 0 {
 		return 0, statusError(t)
 	}
@@ -790,10 +839,10 @@ func statusError(status C.int) error {
 // handle to set it up just the way you'd like.
 type InactiveHandle struct {
 	// cptr is the handle for the actual pcap C object.
-	cptr         *C.pcap_t
-	device       string
-	deviceIndex  int
-	blockForever bool
+	cptr        *C.pcap_t
+	device      string
+	deviceIndex int
+	timeout     time.Duration
 }
 
 // Activate activates the handle.  The current InactiveHandle becomes invalid
@@ -803,7 +852,12 @@ func (p *InactiveHandle) Activate() (*Handle, error) {
 	if err != aeNoError {
 		return nil, err
 	}
-	h := &Handle{cptr: p.cptr, device: p.device, deviceIndex: p.deviceIndex, blockForever: p.blockForever}
+	h := &Handle{
+		cptr:        p.cptr,
+		timeout:     p.timeout,
+		device:      p.device,
+		deviceIndex: p.deviceIndex,
+	}
 	p.cptr = nil
 	return h, nil
 }
@@ -867,10 +921,10 @@ func (p *InactiveHandle) SetPromisc(promisc bool) error {
 //
 // See the package documentation for important details regarding 'timeout'.
 func (p *InactiveHandle) SetTimeout(timeout time.Duration) error {
-	p.blockForever = timeout < 0
 	if status := C.pcap_set_timeout(p.cptr, timeoutMillis(timeout)); status < 0 {
 		return statusError(status)
 	}
+	p.timeout = timeout
 	return nil
 }
 
